@@ -1,7 +1,10 @@
 /**
- * $Id: list.h,v 1.1 2004/06/21 11:28:00 jklein Exp $
+ * $Id: list.h,v 1.2 2004/06/21 16:44:17 jklein Exp $
  * $Author: jklein $
  * $Log: list.h,v $
+ * Revision 1.2  2004/06/21 16:44:17  jklein
+ * Added iterator.
+ *
  * Revision 1.1  2004/06/21 11:28:00  jklein
  * Changed source tree.
  *
@@ -10,11 +13,12 @@
  *
  */
 
+
 #ifndef _SC_LIST_H_
 #define _SC_LIST_H_
 
 #include "scale/commons.h"
-
+#include "scale/iterator.h"
 
 typedef struct _sc_linklist slist_t;
 typedef struct _sc_linklist_node slist_node_t;
@@ -50,6 +54,8 @@ spointer		s_list_remove(slist_t *, size_t);
 sint32			s_list_find(slist_t *, sc_compf_t, spointer);
 sboolean		s_list_join(slist_t *, slist_t *);
 
+siterator_t *	s_list_iterator(slist_t *);
+
 /* this is for debbuging.
  * or you can use this any time. */
 void _sc_dump_list(const char *, slist_t *);
