@@ -1,3 +1,12 @@
+/**
+ * $Id: sc_list.c,v 1.3 2004/06/21 16:44:17 jklein Exp $
+ * $Author: jklein $
+ * $Log: sc_list.c,v $
+ * Revision 1.3  2004/06/21 16:44:17  jklein
+ * Added iterator.
+ *
+ */
+
 
 #include <stdio.h>
 #include "scale/list.h"
@@ -260,3 +269,68 @@ s_list_join(slist_t *dst, slist_t *src)
 	return true;
 }
 
+
+
+typedef struct {
+	slist_node_t *next;
+} list_itr_manager_t;
+
+
+static spointer
+_s_list_iterator_next(siterator_t *itr)
+{
+	list_itr_manager_t *mng;
+	slist_t *list;
+	spointer contents;
+
+	list = (slist_t *)itr->listdata;
+	mng = (list_itr_manager_t *)itr->data;
+
+	if (mng->next == NULL)
+		return NULL;
+
+	contents = mng->next->contents;
+
+	mng->next = (list->tail != mng->next->next)?
+		mng->next->next:NULL;
+	return contents;
+}
+
+
+static void
+_s_list_iterator_clear(siterator_t *itr)
+{
+	list_itr_manager_t *mng;
+	slist_t *list;
+
+	list = (slist_t *)itr->listdata;
+	mng = (list_itr_manager_t *)itr->data;
+
+	mng->next = list->head->next;
+}
+
+
+static void
+_s_list_iterator_free(siterator_t *itr)
+{
+	s_freen(itr->data, sizeof(list_itr_manager_t));
+	s_freen(itr, sizeof(siterator_t));
+}
+
+
+siterator_t *
+s_list_iterator(slist_t *list)
+{
+	siterator_t *itr;
+
+	itr = (siterator_t *)s_malloc(sizeof(siterator_t));
+	itr->listdata = list;
+	itr->data = (list_itr_manager_t *)s_malloc(sizeof(list_itr_manager_t));
+	itr->next = _s_list_iterator_next;
+	itr->clear = _s_list_iterator_clear;
+	itr->free = _s_list_iterator_free;
+
+	itr->clear(itr);
+
+	return itr;
+}
