@@ -1,7 +1,10 @@
 /**
- * $Id: tester.c,v 1.4 2004/06/22 12:23:39 jklein Exp $
+ * $Id: tester.c,v 1.5 2004/06/23 12:59:01 jklein Exp $
  * $Author: jklein $
  * $Log: tester.c,v $
+ * Revision 1.5  2004/06/23 12:59:01  jklein
+ * Added scale/btree.h, sc_btree.c.
+ *
  * Revision 1.4  2004/06/22 12:23:39  jklein
  * correcting mistakes.
  *
@@ -25,6 +28,7 @@
 #include "scale/heap.h"
 #include "scale/commons.h"
 #include "scale/queue.h"
+#include "scale/btree.h"
 #include "scale/iterator.h"
 
 
@@ -395,6 +399,54 @@ test_heap()
 }
 
 
+int
+test_btree(void)
+{
+	sbtree_t *btree;
+
+	FUNC_START();	
+	btree = s_btree_alloc(s_string_compare);
+
+	assert(s_btree_size(btree) == 0);
+	s_btree_add(btree, "a", "A");
+	s_btree_add(btree, "b", "B");
+	s_btree_add(btree, "c", "C");
+	s_btree_add(btree, "d", "D");
+	s_btree_add(btree, "e", "E");
+	assert(s_btree_size(btree) == 5);
+
+	assert(strcmp(s_btree_get(btree, "a"), "A") == 0);
+	assert(strcmp(s_btree_get(btree, "b"), "B") == 0);
+	assert(strcmp(s_btree_get(btree, "c"), "C") == 0);
+	assert(strcmp(s_btree_get(btree, "d"), "D") == 0);
+	assert(strcmp(s_btree_get(btree, "e"), "E") == 0);
+
+	assert(strcmp(s_btree_remove(btree, "a"), "A") == 0);
+	assert(strcmp(s_btree_remove(btree, "b"), "B") == 0);
+	assert(strcmp(s_btree_remove(btree, "c"), "C") == 0);
+	assert(strcmp(s_btree_remove(btree, "d"), "D") == 0);
+	assert(strcmp(s_btree_remove(btree, "e"), "E") == 0);
+	assert(s_btree_size(btree) == 0);
+
+	{
+		siterator_t *itr;
+
+		s_btree_add(btree, "A", "a");
+		s_btree_add(btree, "B", "b");
+		s_btree_add(btree, "C", "c");
+		assert(s_btree_size(btree) == 3);
+
+		itr = s_btree_lfs_iterator(btree);
+		iterator_tester(itr);
+
+		itr->free(itr);
+	}
+
+	s_btree_free(btree);
+	return 1;
+}
+
+
 int
 main(int argc, char *argv[])
 {
@@ -402,6 +454,7 @@ main(int argc, char *argv[])
 	char c;
 	int has_error = 0;
 	testfunc funcs[] = {
+		test_btree,
 		test_heap,
 		test_queue,
 		test_stack,
